var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });

// src/c-scroll-lock.ts
import { defineComponent, withDirectives, cloneVNode } from "vue";

// src/body-scoll-lock.directive.ts
import "vue";
import { enableBodyScroll, disableBodyScroll } from "body-scroll-lock";
var BodyScrollLockDirective = {
  mounted(el, binding) {
    if (el && binding.value) {
      disableBodyScroll(el);
    } else if (el && !binding.value) {
      enableBodyScroll(el);
    }
  },
  updated(el, binding) {
    if (el && binding.value) {
      disableBodyScroll(el);
    } else if (el && !binding.value) {
      enableBodyScroll(el);
    }
  },
  unmounted(el, binding) {
    if (el) {
      enableBodyScroll(el);
    }
  }
};

// src/c-scroll-lock.ts
var CScrollLock = defineComponent({
  name: "CScrollLock",
  props: {
    enabled: {
      type: Boolean,
      default: false
    }
  },
  setup(props, {
    slots,
    attrs
  }) {
    return () => {
      var _a;
      const [firstChild] = (_a = slots.default) == null ? void 0 : _a.call(slots, {});
      if (!firstChild) {
        console.warn(`[chakra-ui:focus-lock]: Focus lock component expects at least and only one child element.`);
        return;
      }
      const scrollLockVNode = cloneVNode(firstChild, {
        ...attrs,
        "data-chakra-scroll-lock": `${props.enabled}`
      });
      return withDirectives(scrollLockVNode, [[BodyScrollLockDirective, props.enabled]]);
    };
  }
});

// src/use-body-scoll-lock.ts
import { enableBodyScroll as enableBodyScroll2, disableBodyScroll as disableBodyScroll2 } from "body-scroll-lock";
import { watch } from "vue";
import { useRef } from "@chakra-ui/vue-utils";
function useBodyScrollLock(enable, options) {
  const [scrollLockRef, scrollLockEl] = useRef();
  watch([scrollLockEl, enable], ([target, isActive], [previousTarget]) => {
    if (!target || !enable.value) {
      previousTarget && enableBodyScroll2(previousTarget);
    } else if (target && isActive) {
      disableBodyScroll2(target, options);
    } else {
      enableBodyScroll2(target);
    }
  }, {
    immediate: true,
    flush: "post"
  });
  return {
    scrollLockRef
  };
}
__name(useBodyScrollLock, "useBodyScrollLock");
export {
  BodyScrollLockDirective,
  CScrollLock,
  useBodyScrollLock
};
